__all__ = ('ProfileScorePoint', 'OrderScorePoint', 'ILScorePoint', 'LocScorePoint')

from expressmoney.api import *


SERVICE = 'scoring'
APP = 'score'


class ProfileScoreCreateContract(Contract):
    pass


class ProfileScoreReadContract(Contract):
    created = serializers.DateTimeField()
    score = serializers.DecimalField(max_digits=3, decimal_places=2)


class ProfileScoreResponseContract(ProfileScoreReadContract):
    pass


class OrderScoreCreateContract(Contract):
    order_id = serializers.IntegerField(min_value=1)


class ILScoreCreateContract(OrderScoreCreateContract):
    pass


class LocScoreCreateContract(OrderScoreCreateContract):
    pass


class OrderScoreResponseContract(Contract):
    created = serializers.DateTimeField()
    score = serializers.DecimalField(max_digits=3, decimal_places=2)
    order_id = serializers.IntegerField(min_value=1)


class ILScoreResponseContract(OrderScoreResponseContract):
    pass


class LocScoreResponseContract(OrderScoreResponseContract):
    pass


class OrderScoreReadContract(OrderScoreResponseContract):
    pass


class ILScoreReadContract(OrderScoreResponseContract):
    pass


class LocScoreReadContract(OrderScoreResponseContract):
    pass


class ProfileScoreID(ID):
    _service = SERVICE
    _app = APP
    _view_set = 'profile_score'


class OrderScoreID(ID):
    _service = SERVICE
    _app = APP
    _view_set = 'order_score'


class ILScoreID(ID):
    _service = SERVICE
    _app = APP
    _view_set = 'il_score'


class LocScoreID(ID):
    _service = SERVICE
    _app = APP
    _view_set = 'loc_score'


class ProfileScorePoint(ListPointMixin, ResponseMixin, CreatePointMixin, ContractPoint):
    _point_id = ProfileScoreID()
    _create_contract = ProfileScoreCreateContract
    _response_contract = ProfileScoreResponseContract
    _read_contract = ProfileScoreReadContract
    _sort_by = 'created'


class OrderScorePoint(ListPointMixin, ResponseMixin, CreatePointMixin, ContractPoint):
    _point_id = OrderScoreID()
    _read_contract = OrderScoreReadContract
    _create_contract = OrderScoreCreateContract
    _response_contract = OrderScoreResponseContract
    _sort_by = 'created'


class ILScorePoint(ListPointMixin, ResponseMixin, CreatePointMixin, ContractPoint):
    _point_id = ILScoreID()
    _read_contract = ILScoreReadContract
    _create_contract = ILScoreCreateContract
    _response_contract = ILScoreResponseContract
    _sort_by = 'created'


class LocScorePoint(ListPointMixin, ResponseMixin, CreatePointMixin, ContractPoint):
    _point_id = LocScoreID()
    _read_contract = LocScoreReadContract
    _create_contract = LocScoreCreateContract
    _response_contract = LocScoreResponseContract
    _sort_by = 'created'



__all__ = ('OrderPoint', 'OrderObjectPoint')

from djmoney.contrib.django_rest_framework import MoneyField
from expressmoney.api import *

SERVICE = 'il'


class OrderCreateContract(Contract):
    requested_period = serializers.IntegerField(min_value=1)
    requested_amount = serializers.IntegerField(min_value=1)
    ip = serializers.IPAddressField()


class OrderReadContract(OrderCreateContract):
    NEW = 'NEW'
    LOAN_CREATED = 'LOAN_CREATED'
    EXPIRED = 'EXPIRED'
    STATUS_CHOICES = (
        (NEW, NEW),
        (LOAN_CREATED, LOAN_CREATED),
        (EXPIRED, EXPIRED),
    )

    id = serializers.IntegerField(min_value=1)
    created = serializers.DateTimeField()
    user_id = serializers.IntegerField(min_value=1)
    status = serializers.ChoiceField(choices=STATUS_CHOICES)
    requested_period = serializers.IntegerField(min_value=1)
    requested_amount = MoneyField(max_digits=7, decimal_places=0)
    approved_period = serializers.IntegerField(min_value=1)
    approved_amount = MoneyField(max_digits=7, decimal_places=0, allow_null=True)
    interest_rate = serializers.DecimalField(max_digits=6, decimal_places=5, allow_null=True)
    score = serializers.DecimalField(max_digits=3, decimal_places=2, allow_null=True)
    sign = serializers.IntegerField(min_value=1)
    contract_demo = serializers.CharField(max_length=256, allow_blank=True)
    ip = serializers.IPAddressField()


class OrderID(ID):
    _service = SERVICE
    _app = 'orders'
    _view_set = 'order'


class OrderPoint(ListPointMixin, CreatePointMixin, ContractPoint):
    _point_id = OrderID()
    _read_contract = OrderReadContract
    _create_contract = OrderCreateContract


class OrderObjectPoint(RetrievePointMixin, ContractObjectPoint):
    _point_id = OrderID()
    _read_contract = OrderReadContract



__all__ = ('UnderwritingTaskPoint', 'BankCardProcessPoint', 'AntifraudProcessPoint')
from expressmoney.api import *

SERVICE = 'profiles'
APP = 'underwriting'


class UnderwritingTaskCreateContract(Contract):
    pass


class BankCardProcessCreateContract(Contract):
    bank_card_id = serializers.IntegerField(min_value=1)
    file = serializers.CharField(max_length=256)


class AntifraudProcessCreateContract(Contract):
    comment = serializers.CharField(max_length=1024)


class UnderwritingTaskID(ID):
    _service = SERVICE
    _app = APP
    _view_set = 'underwriting_task'


class BankCardProcessID(ID):
    _service = SERVICE
    _app = APP
    _view_set = 'bank_card_process'


class AntifraudProcessID(ID):
    _service = SERVICE
    _app = APP
    _view_set = 'antifraudprocess'


class UnderwritingTaskPoint(CreatePointMixin, ContractPoint):
    _point_id = UnderwritingTaskID()
    _create_contract = UnderwritingTaskCreateContract


class BankCardProcessPoint(CreatePointMixin, ContractPoint):
    _point_id = BankCardProcessID()
    _create_contract = BankCardProcessCreateContract


class AntifraudProcessPoint(CreatePointMixin, ContractPoint):
    _point_id = AntifraudProcessID()
    _create_contract = AntifraudProcessCreateContract



__all__ = ('UnderwritingTaskPoint',)

from expressmoney.api import *

SERVICE = 'sync'


class UnderwritingTaskReadContract(Contract):
    created = serializers.DateTimeField(allow_null=True)
    profile = serializers.IntegerField(min_value=1)
    is_success = serializers.BooleanField()


class UnderwritingTaskID(ID):
    _service = SERVICE
    _app = 'underwriting'
    _view_set = 'underwriting_task'


class UnderwritingTaskPoint(ListPointMixin, ContractPoint):
    _point_id = UnderwritingTaskID()
    _read_contract = UnderwritingTaskReadContract
    _sort_by = 'created'
    _cache_enabled = False



__all__ = ('ReferralPoint',)

from django.core.validators import RegexValidator
from expressmoney.api import *

SERVICE = 'partners'


class ReferralCreateContract(Contract):
    partner_code = serializers.CharField(max_length=8,
                                         validators=(RegexValidator(regex='^[A-Z0-9]*$',
                                                                    message='invalid_format',
                                                                    code='invalid_format'
                                                                    ),
                                                     ))


class ReferralReadContract(ReferralCreateContract):
    created = serializers.DateTimeField()
    user_id = serializers.IntegerField(min_value=1)


class ReferralID(ID):
    _service = SERVICE
    _app = 'referrals'
    _view_set = 'referral'


class ReferralPoint(CreatePointMixin, ListPointMixin, ContractPoint):
    _point_id = ReferralID()
    _create_contract = ReferralCreateContract
    _read_contract = ReferralReadContract
